#!/usr/bin/env python

import sys
import subprocess
import numpy as np
from scipy.interpolate import splrep, splev

import colorpy.ciexyz
import colorpy.colormodels

def xyz_(wave, intens):

    xyz = colorpy.ciexyz.xyz_from_wavelength(wave/10.)
    xyz = 0.14*xyz
    xyz = xyz*intens
    return xyz

def rgb_(xyz):

    rgb = colorpy.colormodels.irgb_from_xyz(xyz)
    return rgb

def rel2pnm(src, dst):

    wave = []
    intens = []

    f1 = open(src, "r")

    for line in f1.readlines():
        l = line.split()
        wave.append(float(l[0]))
        intens.append(float(l[1]))

    f1.close()

    wvl0 = 6528.
    wvl1 = 6595.
    newwave = np.linspace(wvl0, wvl1, num=2048)
    spl = splrep(wave, intens)
    newintens = splev(newwave, spl)

    xyz = []
    rgb = []
    for i in xrange(0,len(newwave)):
        xyz.append(xyz_(newwave[i], newintens[i]))
        rgb.append(rgb_(xyz[-1]))

    h = 1
    w = len(newwave)

#    h = 128
#    rgb = np.array(rgb)
#    c = np.zeros(h)
#    rgb3 = rgb[None,:,:] + c[:,None,None]
#    rgb3 = np.reshape(rgb3,(3*w,h))

#    print "c = ", c.shape
#    print "rgb = ", rgb.shape
#    print "rgb3 = ", rgb3.shape

    f2 = open(dst, "w")
    f2.write("P3\n# Created by GIMP version 2.10.8 PNM plug-in\n%d %d\n255\n" % (w,h))

    np.savetxt(f2, rgb, fmt='%d')

#    for j in xrange(0,h):
#        for i in xrange(0,len(rgb)):
#            f2.write("%d %d %d\n" % (rgb[i][0], rgb[i][1], rgb[i][2]))

    f2.close()

    f3 = open("rgb.dat", "w")

    for i in xrange(0,len(rgb)):
        f3.write("%d %d %d\n" % (rgb[i][0], rgb[i][1], rgb[i][2]))

    f3.close()

    f3 = open("xyz.dat", "w")

    for i in xrange(0,len(rgb)):
        f3.write("%f %f %f\n" % (xyz[i][0], xyz[i][1], xyz[i][2]))

    f3.close()

def main():

    files = subprocess.check_output("cd ../Ignace/; ls *.phase", shell=True)
    files = files.split()
#    files = files[:1]

    for fil in files:
        print fil
        src = "../Ignace/" + fil
        dst = fil + ".png"
        tmp = "tmp.pnm"

        rel2pnm(src, tmp)

        cmd = "convert %s -geometry 100%%x12800%% %s" % (tmp, dst)
        subprocess.check_output(cmd, shell=True)

if __name__ == "__main__":
    main()


