/*
 * spectra4.pov
 * Miroslav Broz (miroslav.broz@email.cz), Apr 15th 2020
 */

#version 3.7;

#include "common.pov"

#declare nts=2;
#declare ts = array[nts];
#declare ts[0]=0;
#declare ts[1]=20;

#include "times.pov"
#include "interp.pov"

// phases

#declare phases = array[1000];

#declare i=0;
#macro s(p)
  #declare phases[i]=p;
//  #debug concat("phases[", str(i,3,0), "] = ", str(phases[i],8,6), "\n")
  #declare i=i+1;
#end

#include "phase.pov"

#declare N=i;

#declare phase1 = (interp1(tc[0],tc[1],0,0.999999));
#debug concat("phase1 = ", str(phase1,8,6), "\n")

#declare i=0;
#while (phases[i] < phase1)
  #debug concat("phases[", str(i,3,0), "] = ", str(phases[i],8,6), "\n")
  #declare i=i+1;
#end
#declare phase0 = phases[i];

// spectrum

#declare b = (interp1(tc[0],tc[1],0,0));       // rotation
#declare c = (interp1(tc[0],tc[1],0.25,0.25));  // width
#declare d = (interp1(tc[0],tc[1],0.1,0.1));  // height
#declare e = (interp1(tc[0],tc[1],0.1,0.1));  // position

cylinder {
  <0,-1,0>,
  <0,1,0>,
  1.0
  open
  texture {
    pigment {
      image_map {
        png concat(str(phase0,8,6), ".phase.png")
        map_type 0
        interpolate 2
        once
      }
      scale <c,d,1>
      warp {
        cylindrical
        orientation z
        dist_exp 0
      }
    }
    finish {
      ambient 1.0
      diffuse 0.0
    }
  }
  scale <-1,0,0>
  rotate 360*(0.25-0.5*c)*y
  rotate b*y
  translate <0,e,0.0>
}

// temperature

// lines

#declare g = 0;  // transparency

#macro label(s, v1, d, a, font)
  #local txtobj =
    text {
      ttf font, s, 0.01, 0
      texture {
        pigment {
          color rgbt <1,1,0.95,g>
        }
        finish {
          ambient 1
          diffuse 0
        }
      }
    }
  object {
    txtobj
    #local tmp=-(min_extent(txtobj)+max_extent(txtobj))/2;
    translate tmp.x*x
    scale d
    translate v1
    rotate a*y
    rotate b*y
  }
#end

#macro f(wave)
  360.*c*(-0.5+(wave-6528.)/(6595.-6528.))
#end

#macro line(s, wave)
  label(s, <0,e+d+0.025,0.99>, 0.025, f(wave), "DejaVuSansCondensed.ttf")
#end

line("Hα"    , 6562.8)

// wavelengths

#declare g = 0;

#macro line(s, wave)
  label(s, <0,e-0.035,0.99>, 0.02, f(wave), "GillSans5.ttf")
#end

line("653", 6530)
line("654", 6540)
line("655", 6550)
line("656", 6560)
line("657", 6570)
line("658", 6580)
line("659", 6590)

// camera

camera {
  fisheye
  angle 180
  location <0,0,0>
  look_at <0,1,0>
  right <1,0,0>
}


